import { CompositeLayer, CompositeLayerProps, DefaultProps, GetPickingInfoParams, Layer, LayersList } from "@deck.gl/core";
import type { ColumnLayerProps } from "@deck.gl/layers";
import * as arrow from "apache-arrow";
import * as ga from "@geoarrow/geoarrow-js";
import { ColorAccessor, FloatAccessor, GeoArrowPickingInfo } from "../types";
import { GeoArrowExtraPickingProps } from "../utils/picking";
/** All properties supported by GeoArrowColumnLayer */
export type GeoArrowColumnLayerProps = Omit<ColumnLayerProps<arrow.Table>, "data" | "getPosition" | "getFillColor" | "getLineColor" | "getElevation" | "getLineWidth"> & _GeoArrowColumnLayerProps & CompositeLayerProps;
/** Properties added by GeoArrowColumnLayer */
type _GeoArrowColumnLayerProps = {
    data: arrow.Table;
    /**
     * Method called to retrieve the position of each column.
     */
    getPosition?: ga.vector.PointVector;
    /**
     * Fill color value or accessor.
     * @default [0, 0, 0, 255]
     */
    getFillColor?: ColorAccessor;
    /**
     * Line color value or accessor.
     *
     * @default [0, 0, 0, 255]
     */
    getLineColor?: ColorAccessor;
    /**
     * The elevation of each cell in meters.
     * @default 1000
     */
    getElevation?: FloatAccessor;
    /**
     * The width of the outline of the column, in units specified by `lineWidthUnits`.
     *
     * @default 1
     */
    getLineWidth?: FloatAccessor;
    /**
     * If `true`, validate the arrays provided (e.g. chunk lengths)
     * @default true
     */
    _validate?: boolean;
};
/**
 * Render extruded cylinders (tessellated regular polygons) at given
 * coordinates.
 */
export declare class GeoArrowColumnLayer<ExtraProps extends {} = {}> extends CompositeLayer<GeoArrowColumnLayerProps & ExtraProps> {
    static defaultProps: DefaultProps<GeoArrowColumnLayerProps>;
    static layerName: string;
    getPickingInfo(params: GetPickingInfoParams & {
        sourceLayer: {
            props: GeoArrowExtraPickingProps;
        };
    }): GeoArrowPickingInfo;
    renderLayers(): Layer<{}> | LayersList | null;
    _renderLayersPoint(geometryColumn: ga.vector.PointVector): Layer<{}> | LayersList | null;
}
export {};
