// deck.gl-community
// SPDX-License-Identifier: MIT
// Copyright (c) vis.gl contributors
import { CompositeLayer, } from "@deck.gl/core";
import { H3HexagonLayer } from "@deck.gl/geo-layers";
import { assignAccessor, extractAccessorsFromProps } from "../utils/utils";
import { computeChunkOffsets, getPickingInfo, } from "../utils/picking";
import { validateAccessors } from "../utils/validate";
// Remove data from the upstream default props
const { data: _data, getHexagon: _getHexagon, ..._defaultProps } = H3HexagonLayer.defaultProps;
// Default props added by us
const ourDefaultProps = {
    _validate: true,
};
const defaultProps = {
    ..._defaultProps,
    ...ourDefaultProps,
};
export class GeoArrowH3HexagonLayer extends CompositeLayer {
    static defaultProps = defaultProps;
    static layerName = "GeoArrowH3HexagonLayer";
    getPickingInfo(params) {
        return getPickingInfo(params, this.props.data);
    }
    renderLayers() {
        return this._renderLayersPoint();
    }
    _renderLayersPoint() {
        const { data: table, getHexagon: hexagonColumn } = this.props;
        if (this.props._validate) {
            validateAccessors(this.props, table);
        }
        // Exclude manually-set accessors
        const [accessors, otherProps] = extractAccessorsFromProps(this.props, [
            "getHexagon",
        ]);
        const tableOffsets = computeChunkOffsets(table.data);
        const layers = [];
        for (let recordBatchIdx = 0; recordBatchIdx < table.batches.length; recordBatchIdx++) {
            const hexData = hexagonColumn.data[recordBatchIdx];
            const hexValues = hexData.values;
            const props = {
                // Note: because this is a composite layer and not doing the rendering
                // itself, we still have to pass in our defaultProps
                ...ourDefaultProps,
                ...otherProps,
                // used for picking purposes
                recordBatchIdx,
                tableOffsets,
                id: `${this.props.id}-geoarrow-arc-${recordBatchIdx}`,
                data: {
                    // @ts-expect-error passed through to enable use by function accessors
                    data: table.batches[recordBatchIdx],
                    length: hexData.length,
                    attributes: {
                        getHexagon: {
                            value: hexValues,
                            // h3 cells should always be 15 characters...?
                            size: 15,
                        },
                    },
                },
            };
            for (const [propName, propInput] of Object.entries(accessors)) {
                assignAccessor({
                    props,
                    propName,
                    propInput,
                    chunkIdx: recordBatchIdx,
                });
            }
            const layer = new H3HexagonLayer(this.getSubLayerProps(props));
            layers.push(layer);
        }
        return layers;
    }
}
