import { CompositeLayer, CompositeLayerProps, DefaultProps, Layer, LayersList } from "@deck.gl/core";
import type { HeatmapLayerProps } from "@deck.gl/aggregation-layers";
import * as arrow from "apache-arrow";
import * as ga from "@geoarrow/geoarrow-js";
import { FloatAccessor } from "../types";
/** All properties supported by GeoArrowHeatmapLayer */
export type GeoArrowHeatmapLayerProps = Omit<HeatmapLayerProps, "data" | "getPosition" | "getWeight"> & _GeoArrowHeatmapLayerProps & CompositeLayerProps;
/** Properties added by GeoArrowHeatmapLayer */
type _GeoArrowHeatmapLayerProps = {
    data: arrow.Table;
    /**
     * Method called to retrieve the position of each object.
     *
     * @default d => d.position
     */
    getPosition?: ga.vector.PointVector;
    /**
     * The weight of each object.
     *
     * @default 1
     */
    getWeight?: FloatAccessor;
    /**
     * If `true`, validate the arrays provided (e.g. chunk lengths)
     * @default true
     */
    _validate?: boolean;
};
export declare class GeoArrowHeatmapLayer<ExtraProps extends {} = {}> extends CompositeLayer<GeoArrowHeatmapLayerProps & ExtraProps> {
    static defaultProps: DefaultProps<GeoArrowHeatmapLayerProps>;
    static layerName: string;
    renderLayers(): Layer<{}> | LayersList | null;
    _renderLayersPoint(geometryColumn: ga.vector.PointVector): Layer<{}> | LayersList | null;
}
export {};
