import { CompositeLayer, CompositeLayerProps, DefaultProps, GetPickingInfoParams, Layer, LayersList } from "@deck.gl/core";
import type { PathLayerProps } from "@deck.gl/layers";
import * as arrow from "apache-arrow";
import * as ga from "@geoarrow/geoarrow-js";
import { GeoArrowExtraPickingProps } from "../utils/picking";
import { ColorAccessor, FloatAccessor, GeoArrowPickingInfo } from "../types";
/** All properties supported by GeoArrowPathLayer */
export type GeoArrowPathLayerProps = Omit<PathLayerProps<arrow.Table>, "data" | "getPath" | "getColor" | "getWidth"> & _GeoArrowPathLayerProps & CompositeLayerProps;
/** Properties added by GeoArrowPathLayer */
type _GeoArrowPathLayerProps = {
    data: arrow.Table;
    /**
     * If `true`, validate the arrays provided (e.g. chunk lengths)
     * @default true
     */
    _validate?: boolean;
    /**
     * Path geometry accessor.
     */
    getPath?: ga.vector.LineStringVector | ga.vector.MultiLineStringVector;
    /**
     * Path color accessor.
     * @default [0, 0, 0, 255]
     */
    getColor?: ColorAccessor;
    /**
     * Path width accessor.
     * @default 1
     */
    getWidth?: FloatAccessor;
};
export declare const defaultProps: DefaultProps<GeoArrowPathLayerProps>;
/**
 * Render lists of coordinate points as extruded polylines with mitering.
 */
export declare class GeoArrowPathLayer<ExtraProps extends {} = {}> extends CompositeLayer<GeoArrowPathLayerProps & ExtraProps> {
    static defaultProps: DefaultProps<GeoArrowPathLayerProps>;
    static layerName: string;
    getPickingInfo(params: GetPickingInfoParams & {
        sourceLayer: {
            props: GeoArrowExtraPickingProps;
        };
    }): GeoArrowPickingInfo;
    renderLayers(): Layer<{}> | LayersList | null;
    _renderLayersLineString(geometryColumn: ga.vector.LineStringVector): Layer<{}> | LayersList | null;
    _renderLayersMultiLineString(geometryColumn: ga.vector.MultiLineStringVector): Layer<{}> | LayersList | null;
}
export {};
