import { CompositeLayer, CompositeLayerProps, DefaultProps, GetPickingInfoParams, Layer, LayersList } from "@deck.gl/core";
import type { PointCloudLayerProps } from "@deck.gl/layers";
import * as arrow from "apache-arrow";
import * as ga from "@geoarrow/geoarrow-js";
import { GeoArrowExtraPickingProps } from "../utils/picking";
import { ColorAccessor, GeoArrowPickingInfo, NormalAccessor } from "../types";
export type GeoArrowPointCloudLayerProps = Omit<PointCloudLayerProps<arrow.Table>, "data" | "getPosition" | "getNormal" | "getColor"> & _GeoArrowPointCloudLayerProps & CompositeLayerProps;
type _GeoArrowPointCloudLayerProps = {
    data: arrow.Table;
    /**
     * If `true`, validate the arrays provided (e.g. chunk lengths)
     * @default true
     */
    _validate?: boolean;
    /**
     * Center position accessor.
     * If not provided, will be inferred by finding a column with extension type
     * `"geoarrow.point"`
     */
    getPosition?: ga.vector.PointVector;
    /**
     * The normal of each object, in `[nx, ny, nz]`.
     * @default [0,0,1]
     */
    getNormal?: NormalAccessor;
    /**
     * The rgba color is in the format of `[r, g, b, [a]]`
     * @default [0,0,0,225]
     */
    getColor?: ColorAccessor;
};
export declare class GeoArrowPointCloudLayer<ExtraProps extends {} = {}> extends CompositeLayer<GeoArrowPointCloudLayerProps & ExtraProps> {
    static defaultProps: DefaultProps<GeoArrowPointCloudLayerProps>;
    static layerName: string;
    getPickingInfo(params: GetPickingInfoParams & {
        sourceLayer: {
            props: GeoArrowExtraPickingProps;
        };
    }): GeoArrowPickingInfo;
    renderLayers(): Layer<{}> | LayersList | null;
    _renderLayersPoint(geometryColumn: ga.vector.PointVector): Layer<{}> | LayersList | null;
}
export {};
