import { CompositeLayer, CompositeLayerProps, DefaultProps, Layer, LayersList, GetPickingInfoParams, LayerContext, UpdateParameters } from "@deck.gl/core";
import type { SolidPolygonLayerProps } from "@deck.gl/layers";
import * as arrow from "apache-arrow";
import * as ga from "@geoarrow/geoarrow-js";
import { GeoArrowExtraPickingProps } from "../utils/picking";
import { ColorAccessor, FloatAccessor, GeoArrowPickingInfo } from "../types";
import { Pool } from "threads";
import type { FunctionThread } from "threads";
/** All properties supported by GeoArrowSolidPolygonLayer */
export type GeoArrowSolidPolygonLayerProps = Omit<SolidPolygonLayerProps, "data" | "getPolygon" | "getElevation" | "getFillColor" | "getLineColor"> & _GeoArrowSolidPolygonLayerProps & CompositeLayerProps;
/** Properties added by GeoArrowSolidPolygonLayer */
type _GeoArrowSolidPolygonLayerProps = {
    data: arrow.Table;
    /** Polygon geometry accessor. */
    getPolygon?: ga.vector.PolygonVector | ga.vector.MultiPolygonVector;
    /** Extrusion height accessor.
     * @default 1000
     */
    getElevation?: FloatAccessor;
    /** Fill color accessor.
     * @default [0, 0, 0, 255]
     */
    getFillColor?: ColorAccessor;
    /** Stroke color accessor.
     * @default [0, 0, 0, 255]
     */
    getLineColor?: ColorAccessor;
    /**
     * If `true`, validate the arrays provided (e.g. chunk lengths)
     * @default true
     */
    _validate?: boolean;
    /**
     * URL to worker that performs earcut triangulation.
     *
     * By default this loads from the jsdelivr CDN, but end users may want to host
     * this on their own domain.
     */
    earcutWorkerUrl?: string | URL | null;
    /**
     * The number of workers used for the earcut thread pool.
     */
    earcutWorkerPoolSize?: number;
};
export declare class GeoArrowSolidPolygonLayer<ExtraProps extends {} = {}> extends CompositeLayer<GeoArrowSolidPolygonLayerProps & ExtraProps> {
    static defaultProps: DefaultProps<GeoArrowSolidPolygonLayerProps>;
    static layerName: string;
    state: CompositeLayer["state"] & {
        table: arrow.Table | null;
        tableOffsets: Uint16Array | null;
        triangles: Uint32Array[] | null;
        earcutWorkerPool: Pool<FunctionThread> | null;
        earcutWorkerRequest: Promise<string> | null;
    };
    initializeState(_context: LayerContext): void;
    initEarcutPool(): Promise<Pool<FunctionThread> | null>;
    finalizeState(context: LayerContext): Promise<void>;
    updateData(): Promise<void>;
    _updateEarcut(table: arrow.Table): Promise<Uint32Array[]>;
    _earcutPolygonVector(geometryColumn: ga.vector.PolygonVector): Promise<Uint32Array[]>;
    _earcutPolygonVectorMainThread(geometryColumn: ga.vector.PolygonVector): Uint32Array[];
    _earcutMultiPolygonVector(geometryColumn: ga.vector.MultiPolygonVector): Promise<Uint32Array[]>;
    _earcutMultiPolygonVectorMainThread(geometryColumn: ga.vector.MultiPolygonVector): Uint32Array[];
    updateState({ props, changeFlags }: UpdateParameters<this>): void;
    getPickingInfo(params: GetPickingInfoParams & {
        sourceLayer: {
            props: GeoArrowExtraPickingProps;
        };
    }): GeoArrowPickingInfo;
    renderLayers(): Layer<{}> | LayersList | null;
    _renderLayersPolygon(geometryColumn: ga.vector.PolygonVector): Layer<{}> | LayersList | null;
    _renderLayersMultiPolygon(geometryColumn: ga.vector.MultiPolygonVector): Layer<{}> | LayersList | null;
}
export {};
