import { CompositeLayer, CompositeLayerProps, DefaultProps, Layer, LayersList } from "@deck.gl/core";
import { TripsLayerProps } from "@deck.gl/geo-layers";
import * as arrow from "apache-arrow";
import * as ga from "@geoarrow/geoarrow-js";
import { TimestampAccessor, ColorAccessor, FloatAccessor } from "../types";
/** All properties supported by GeoArrowTripsLayer */
export type GeoArrowTripsLayerProps = Omit<TripsLayerProps<arrow.Table>, "data" | "getPath" | "getColor" | "getWidth" | "getTimestamps"> & _GeoArrowTripsLayerProps & CompositeLayerProps;
/** Properties added by GeoArrowTripsLayer */
type _GeoArrowTripsLayerProps = {
    data: arrow.Table;
    /**
     * If `true`, validate the arrays provided (e.g. chunk lengths)
     * @default true
     */
    _validate?: boolean;
    /**
     * Path geometry accessor.
     */
    getPath?: ga.vector.LineStringVector;
    /**
     * Path color accessor.
     * @default [0, 0, 0, 255]
     */
    getColor?: ColorAccessor;
    /**
     * Path width accessor.
     * @default 1
     */
    getWidth?: FloatAccessor;
    /**
     * Timestamp accessor.
     */
    getTimestamps: TimestampAccessor;
};
/** Render animated paths that represent vehicle trips. */
export declare class GeoArrowTripsLayer<ExtraProps extends {} = {}> extends CompositeLayer<GeoArrowTripsLayerProps & ExtraProps> {
    static defaultProps: DefaultProps<GeoArrowTripsLayerProps>;
    static layerName: string;
    renderLayers(): Layer<{}> | LayersList | null;
    _renderLayersLineString(geometryColumn: ga.vector.LineStringVector): Layer<{}> | LayersList | null;
}
export {};
